@@ -9,8 +9,8 @@
 use std::cmp;
 
 use bls_signature_aggregator::Proof;
-use sn_messaging::DstLocation;
-use xor_name::{Prefix, XorName};
+use sn_messaging::{DestInfo, DstLocation};
+use xor_name::XorName;
 
 use crate::{
     agreement::{Proposal, Proven},
@@ -18,7 +18,7 @@ use crate::{
     messages::{Message, PlainMessage, Variant},
     routing::command::Command,
     section::{MemberInfo, PeerState, SectionAuthorityProvider},
-    Event, SectionChain, MIN_AGE,
+    Error, Event, SectionChain, MIN_AGE,
 };
 
 use super::Core;
@@ -45,22 +45,30 @@ impl Core {
             Proposal::OurElders(section_auth) => {
                 self.handle_our_elders_agreement(section_auth, proof)
             }
-            Proposal::TheirKey { prefix, key } => {
-                self.handle_their_key_agreement(prefix, key, proof);
-                Ok(vec![])
-            }
-            Proposal::TheirKnowledge { prefix, key } => {
-                self.handle_their_knowledge_agreement(prefix, key, proof);
-                Ok(vec![])
-            }
             Proposal::AccumulateAtSrc {
                 message,
                 proof_chain,
-            } => Ok(vec![self.handle_accumulate_at_src_agreement(
-                *message,
-                proof_chain,
-                proof,
-            )?]),
+            } => {
+                let dest_name = if let Some(name) = message.dst.name() {
+                    name
+                } else {
+                    error!(
+                        "Not handling AccumulateAtSrc {:?}: No dst_name found",
+                        *message
+                    );
+                    return Err(Error::InvalidDstLocation);
+                };
+                let dest_section_pk = message.dst_key;
+                Ok(vec![self.handle_accumulate_at_src_agreement(
+                    *message,
+                    proof_chain,
+                    proof,
+                    DestInfo {
+                        dest: dest_name,
+                        dest_section_pk,
+                    },
+                )?])
+            }
             Proposal::JoinsAllowed(joins_allowed) => {
                 self.joins_allowed = joins_allowed;
                 Ok(vec![])
@@ -181,15 +189,15 @@ impl Core {
     ) -> Result<Vec<Command>> {
         let mut commands = vec![];
 
-        let equal_or_extension = section_auth.prefix == *self.section.prefix()
-            || section_auth.prefix.is_extension_of(self.section.prefix());
-        let section_auth = Proven::new(section_auth, proof);
+        let equal_or_extension = section_auth.prefix() == *self.section.prefix()
+            || section_auth.prefix().is_extension_of(self.section.prefix());
+        let section_auth = Proven::new(section_auth, proof.clone());
 
         if equal_or_extension {
             // Our section of sub-section
 
             let infos = self.section.promote_and_demote_elders(&self.node.name());
-            if !infos.contains(&section_auth.value) {
+            if !infos.contains(&section_auth.value.elder_candidates()) {
                 // SectionInfo out of date, ignore.
                 return Ok(commands);
             }
@@ -200,7 +208,7 @@ impl Core {
                 .iter()
                 .flat_map(|info| info.peers())
                 .filter(|peer| !self.section.is_elder(peer.name()))
-                .map(|peer| *peer.addr())
+                .map(|peer| (*peer.name(), *peer.addr()))
                 .collect();
             if !sync_recipients.is_empty() {
                 let sync_message = Message::single_src(
@@ -211,12 +219,16 @@ impl Core {
                         network: self.network.clone(),
                     },
                     None,
-                    None,
                 )?;
+                let len = sync_recipients.len();
                 commands.push(Command::send_message_to_nodes(
-                    &sync_recipients,
-                    sync_recipients.len(),
+                    sync_recipients,
+                    len,
                     sync_message.to_bytes(),
+                    DestInfo {
+                        dest: XorName::random(),
+                        dest_section_pk: proof.public_key,
+                    },
                 ));
             }
 
@@ -266,32 +278,19 @@ impl Core {
         self.update_state(snapshot)
     }
 
-    fn handle_their_key_agreement(&mut self, prefix: Prefix, key: bls::PublicKey, proof: Proof) {
-        let key = Proven::new((prefix, key), proof);
-        let _ = self.network.update_their_key(key);
-    }
-
-    fn handle_their_knowledge_agreement(
-        &mut self,
-        prefix: Prefix,
-        knowledge: bls::PublicKey,
-        proof: Proof,
-    ) {
-        let knowledge = Proven::new((prefix, knowledge), proof);
-        self.network.update_knowledge(knowledge)
-    }
-
     fn handle_accumulate_at_src_agreement(
         &self,
         message: PlainMessage,
         proof_chain: SectionChain,
         proof: Proof,
+        dest_info: DestInfo,
     ) -> Result<Command> {
         let message = Message::section_src(message, proof, proof_chain)?;
 
         Ok(Command::HandleMessage {
             message,
             sender: None,
+            dest_info,
         })
     }
 }
