@@ -19,7 +19,6 @@ use crate::{
     Error, Event, SectionChain,
 };
 use bytes::Bytes;
-use sn_data_types::PublicKey as EndUserPK;
 use sn_messaging::{
     section_info::{Error as TargetSectionError, SectionInfo},
     DestInfo, EndUser, Itinerary, SrcLocation,
@@ -43,11 +42,8 @@ impl Core {
         self.end_users.get_socket_addr(id)
     }
 
-    pub fn get_all_socket_addr<'a>(
-        &'a self,
-        end_user: &'a EndUserPK,
-    ) -> impl Iterator<Item = &'a SocketAddr> {
-        self.end_users.get_all_socket_addr(end_user)
+    pub fn try_add(&mut self, sender: SocketAddr) -> Result<EndUser> {
+        self.end_users.try_add(sender)
     }
 
     pub fn node(&self) -> &Node {
@@ -250,8 +246,7 @@ impl Core {
         // If the msg is to be aggregated at dst, we don't vote among our peers, we simply send the
         // msg as our vote to the dst.
         let msg = if itinerary.aggregate_at_dst() {
-            let proof_chain =
-                self.create_proof_chain(&itinerary.dst, additional_proof_chain_key)?;
+            let proof_chain = self.create_proof_chain(additional_proof_chain_key)?;
             Message::for_dst_accumulation(
                 self.section_keys_provider.key_share()?,
                 itinerary.src.name(),
